@@ -1,7 +1,9 @@
 package Log::ger::Output::Screen;
 
-our $DATE = '2020-02-06'; # DATE
-our $VERSION = '0.009'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-03-06'; # DATE
+our $DIST = 'Log-ger-Output-Screen'; # DIST
+our $VERSION = '0.010'; # VERSION
 
 use strict;
 use warnings;
@@ -70,40 +72,14 @@ sub get_hooks {
     my $formatter = $conf{formatter};
 
     return {
-        # we provide two versions for testing, one using create_log_routine and
-        # one using create_logml_routine. by default, create_logml_routine will
-        # take precendence.
-
         create_log_routine => [
             __PACKAGE__, # key
             50,          # priority
             sub {        # hook
-                my %hook_args = @_;
+                my %hook_args = @_; # see Log::ger::Manual::Internals/"Arguments passed to hook"
                 my $logger = sub {
-                    my $level = $hook_args{level};
-                    my $msg = $_[1];
-                    if ($formatter) {
-                        $msg = $formatter->($msg);
-                    }
-                    hook_before_log({ _fh=>$handle }, $msg);
-                    if ($use_color) {
-                        print $handle _pick_color($level), $msg, "\e[0m";
-                    } else {
-                        print $handle $msg;
-                    }
-                    hook_after_log({ _fh=>$handle }, $msg);
-                };
-                [$logger];
-            }],
-        create_logml_routine => [
-            __PACKAGE__, # key
-            50,          # priority
-            sub {        # hook
-                my %hook_args = @_;
-                my $logger = sub {
-                    my $level = Log::ger::Util::numeric_level($_[1]);
-                    return if $level > $Log::ger::Current_Level;
-                    my $msg = $_[2];
+                    my ($init_args, $msg, $meta) = @_;
+                    my $level = $meta ? $meta->{level} : $hook_args{level};
                     if ($formatter) {
                         $msg = $formatter->($msg);
                     }
@@ -135,7 +111,7 @@ Log::ger::Output::Screen - Output log to screen
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
